@@ -56,14 +56,13 @@ void BlockDeviceList::build(MProcess &proc)
 
     // expressions for matching various partition types
     const QRegularExpression rxESP("^(c12a7328-f81f-11d2-ba4b-00a0c93ec93b|0xef)$");
-    const QRegularExpression rxSwap("^(swap)$");
     const QRegularExpression rxNative("^(0x83|0fc63daf-8483-4772-8e79-3d69d8477de4" // Linux data
                                       "|0x82|0657fd6d-a4ab-43c4-84e5-0933c84b4f4f" // Linux swap
                                       "|44479540-f297-41b2-9af7-d131d5f0458a" // Linux /root x86
                                       "|4f68bce3-e8cd-4db1-96e7-fbcaf984b709" // Linux /root x86-64
                                       "|933ac7e1-2eb4-4f13-b844-0e14e2aef915)$"); // Linux /home
     const QRegularExpression rxWinLDM("^(0x42|5808c8aa-7e8f-42e0-85d2-e1e90434cfb3"
-                                      "|e3c9e316-0b5c-4db8-817d-f92df00215ae)$"); // Windows LDM
+                                      "|af9b60a0-1431-4f62-bc68-3311714a69ad)$"); // Windows LDM
     const QRegularExpression rxNativeFS("^(btrfs|ext2|ext3|ext4|jfs|nilfs2|reiser4|reiserfs|ufs|xfs)$");
 
     QString bootUUID;
@@ -72,8 +71,7 @@ void BlockDeviceList::build(MProcess &proc)
         bootUUID = livecfg.value("BOOT_UUID").toString();
     }
 
-    // backup detection for drives that don't have UUID for ESP
-    const QStringList backup_list = proc.execOutLines("fdisk -l -o DEVICE,TYPE |grep 'EFI System' |cut -d\\  -f1 | cut -d/ -f3");
+    QStringList backup_list; // Backup ESP detection. Populated when needed.
 
     // collect and sort lsblk info (sorting required for drives with >15 partitions)
     const QStringList &bdraw = proc.execOutLines("lsblk -brno TYPE,NAME,UUID,SIZE,PARTTYPE,FSTYPE,LABEL,MODEL");
@@ -119,20 +117,21 @@ void BlockDeviceList::build(MProcess &proc)
         if (segsize > 4) {
             const QString &seg4 = bdsegs.at(4);
             bdinfo.isESP = (seg4.count(rxESP) >= 1);
-           // bdinfo.isSwap = (seg4.count(rxSwap) >= 1);
             bdinfo.isNative = (seg4.count(rxNative) >= 1);
             if (!bdinfo.isNasty) bdinfo.isNasty = (seg4.count(rxWinLDM) >= 1);
         } else {
-            bdinfo.isESP = bdinfo.isSwap = bdinfo.isNative = false;
+            bdinfo.isESP = bdinfo.isNative = false;
         }
 
         if (!bdinfo.isDrive && !bdinfo.isESP) {
-            // check the backup ESP detection list
+            // Backup detection for drives that don't have UUID for ESP.
+            if(backup_list.isEmpty()) {
+                backup_list = proc.execOutLines("fdisk -l -o DEVICE,TYPE"
+                    " | grep 'EFI System' |cut -d\\  -f1 | cut -d/ -f3");
+            }
             bdinfo.isESP = backup_list.contains(bdinfo.name);
         }
         if (segsize > 5) {
-            const QString &seg5 = bdsegs.at(5);
-            bdinfo.isSwap = (seg5.count(rxSwap) >= 1);
             bdinfo.fs = bdsegs.at(5);
             if(bdinfo.fs.count(rxNativeFS) >= 1) bdinfo.isNative = true;
         }
@@ -157,11 +156,11 @@ void BlockDeviceList::build(MProcess &proc)
     }
 
     // debug
-    qDebug() << "Name Size Model FS | isDisk isGPT isBoot isESP isNative isSwap";
+    qDebug() << "Name Size Model FS | isDisk isGPT isBoot isESP isNative";
     for (const BlockDeviceInfo &bdi : *this) {
         qDebug() << bdi.name << bdi.size << bdi.model << bdi.fs << "|"
                  << bdi.isDrive << bdi.isGPT << bdi.isBoot << bdi.isESP
-                 << bdi.isNative << bdi.isSwap;
+                 << bdi.isNative;
     }
 }
 
